# Command Line Interface (CLI)

This section contains the API reference for the CLI. For more information on how to use the CLI, see [Tutorial - CLI](../sections/how_to_guides/advanced/cli/index.md).

## Utility functions for the `distilabel pipeline` sub-commands

Here are some utility functions to help working with the pipelines in the console.

:::distilabel.cli.pipeline.utils
